在大厂中，Git 提交注释的规范性非常重要，因为它直接影响代码的可维护性和团队协作效率。一个好的提交注释应该清晰、简洁、结构化，能够让其他开发者快速理解这次提交的目的和内容。

以下是常见的 **Git 提交注释规范** 和一个完整的中文例子：

---

### **1. Git 提交注释的基本格式**

```plaintext
<类型>: <简短描述>

[可选的详细描述]

[可选的关联信息，例如 Jira 任务编号]
```

#### **字段说明**
1. **类型（Type）**：
   - 用于标识提交的性质，通常有以下几种常见类型：
     - `feat`：新功能（Feature）
     - `fix`：修复 Bug
     - `docs`：文档更新（Documentation）
     - `style`：代码格式调整（不影响逻辑，如空格、缩进等）
     - `refactor`：重构代码（既不是新功能也不是修复 Bug）
     - `test`：添加或修改测试用例
     - `chore`：构建或工具变更（如依赖升级、配置文件修改）
     - `perf`：性能优化

2. **简短描述**：
   - 简明扼要地描述本次提交的内容。
   - 一般不超过 50 个字符，使用现在时态（即描述“做了什么”，而不是“将要做”）。

3. **详细描述（可选）**：
   - 如果提交内容比较复杂，可以补充详细的背景信息或实现细节。
   - 使用段落形式，每行不超过 72 个字符。

4. **关联信息（可选）**：
   - 关联到项目管理工具中的任务编号，例如 Jira 的任务 ID 或 GitHub 的 Issue 编号。
   - 例如：`JIRA-123` 或 `Fixes #456`。

---

### **2. 完整的中文例子**

#### **示例 1：新增功能**
```plaintext
feat: 添加用户登录功能

实现了用户登录接口的调用和错误处理逻辑。
- 增加了 `/login` 接口的请求封装。
- 处理了用户名或密码错误的情况。
- 更新了登录页面的 UI 样式。

JIRA-456
```

#### **示例 2：修复 Bug**
```plaintext
fix: 修复商品详情页图片加载失败的问题

问题原因：
- 商品详情页的图片 URL 拼接错误，导致图片无法正常加载。

解决方案：
- 修改了图片 URL 的拼接逻辑，确保路径正确。
- 增加了对图片加载失败的兜底处理。

JIRA-789
```

#### **示例 3：文档更新**
```plaintext
docs: 更新 README 文件

补充了项目的安装步骤和运行命令说明。
- 添加了如何启动开发服务器的详细说明。
- 更新了环境变量的配置方法。

```

#### **示例 4：代码格式调整**
```plaintext
style: 调整代码缩进和格式

- 统一了所有文件的缩进为 2 个空格。
- 删除了多余的空行。
- 修复了 ESLint 报告的格式问题。

```

#### **示例 5：重构代码**
```plaintext
refactor: 优化购物车模块的代码结构

- 将购物车逻辑拆分为独立的 utils 文件。
- 提取了重复的计算逻辑到公共函数中。
- 改进了代码的可读性和复用性。

JIRA-101
```

#### **示例 6：性能优化**
```plaintext
perf: 优化首页加载速度

- 减少了不必要的 API 请求次数。
- 使用懒加载技术加载图片资源。
- 首页加载时间从 3 秒降低到 1 秒。

JIRA-202
```

---

### **3. 注意事项**

1. **保持简洁**：
   - 简短描述尽量控制在一行以内，避免过于冗长。
   - 详细描述部分可以分段说明，但也要避免过度啰嗦。

2. **一致性**：
   - 团队内部需要统一提交注释的格式，建议制定一份提交规范文档。

3. **关联任务**：
   - 如果项目使用了 Jira、Trello 或 GitHub Issues 等工具，务必在提交注释中关联相关任务编号，方便追踪。

4. **避免模糊描述**：
   - 不要使用模糊的词汇，如“修复了一些问题”或“做了一些改动”。应该具体说明改动的内容。

5. **自动化工具**：
   - 可以使用工具（如 `commitlint`）来强制执行提交注释的规范，确保团队成员遵守规则。

---

### **4. 总结**

在大厂中，良好的 Git 提交注释不仅能提升代码的可维护性，还能帮助团队成员快速理解每次提交的意图。通过遵循上述格式和规范，可以让提交历史更加清晰、专业。

以下是一个完整的中文模板供参考：
```plaintext
<类型>: <简短描述>

[详细描述]

[关联任务编号]
```